| Title: | Print a Daily Bible Proverb to Console |
|---|---|
| Description: | A simple package to grab a Bible proverb corresponding to the day of the month. |
| Authors: | Brad Lindblad [aut, cre, cph] |
| Maintainer: | Brad Lindblad <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.4.0.9000 |
| Built: | 2026-05-11 07:28:43 UTC |
| Source: | https://github.com/bradlindblad/proverbs |
Prints out a daily proverb corresponding to the current day of the month. For example, on the 27th of August, Proverbs 27 would be returned.
proverb(translation = "web", main_color = "cyan", accent_color = "silver")proverb(translation = "web", main_color = "cyan", accent_color = "silver")
translation |
A character string that is available from list returned by |
main_color |
A character string of a color available in the crayon package. The color for the main body of text. |
accent_color |
A character string of a color available in the crayon package. The accent color for the passage. |
nothing
Several open source translations are available. By default, the World English Bible version is returned.
To see which translations are available, use the translations() function.
## Not run: # Return the default translation, which is "web", or World English Bible proverb() # Return the King James version verse of the day proverb(translation="kjv") # Custom colors proverb(main_color="red", accent_color="silver") ## End(Not run)## Not run: # Return the default translation, which is "web", or World English Bible proverb() # Return the King James version verse of the day proverb(translation="kjv") # Custom colors proverb(main_color="red", accent_color="silver") ## End(Not run)
A simple package to grab a Bible proverb corresponding to the day of the month.
Maintainer: Brad Lindblad [email protected] [copyright holder]
Useful links:
Report bugs at https://github.com/bradlindblad/proverbs/issues
Lists available Bible Versions for proverb()
translations()translations()
nothing
## Not run: translations() ## End(Not run)## Not run: translations() ## End(Not run)